@@ -17,7 +17,6 @@ import requests
 
 from .exceptions import (
     ErrorResponse,
-    NonExistantResource,
     CannotConnectToAddress,
     ResourceDeleted,
     IncorrectNestedResourceKwargs,
@@ -43,6 +42,7 @@ class TastyApi(object):
         self._sess_lock = PickleLock()
         self._auth = None
         self._auth_lock = PickleLock()
+        self.verify = True
 
     def _session(self):
         if self._sess is None:
@@ -61,6 +61,7 @@ class TastyApi(object):
                     data=data,
                     headers=self._headers(),
                     auth=self.auth,
+                    verify=self.verify,
             )
             response.raise_for_status()
             return response.json()
@@ -69,7 +70,7 @@ class TastyApi(object):
                 if response.text:
                     args = (response.text, err, url, params, data)
                     if 'NotFound: Invalid resource' in response.text:
-                        raise NonExistantResource(*args)
+                        raise AttributeError(*args)
                     if 'KeyError: ' in response.text:
                         raise IncorrectNestedResourceKwargs(*args)
                     raise ErrorResponse(*args)
@@ -120,7 +121,7 @@ class TastyApi(object):
             uri_cutoff -= 1
             if self.address().endswith(uri[:uri_cutoff]):
                 return self.address() + uri[uri_cutoff:]
-        raise BadUri('Could not find full uri. Address = "{0}", URI = "{1}"'.format(self.address(), uri))
+        raise BadUri(u'Could not find full uri. Address = "{0}", URI = "{1}"'.format(self.address(), uri))
 
     def paginate(self, url, **kwargs):
         """Retrieve the objects for a given resource type.
@@ -235,11 +236,16 @@ class TastyApi(object):
         :type resource: str
         :returns: A wrapper around the resource's schema.
         :rtype: TastySchema
-        :raises: NonExistantResource
         """
-        try:
-            url += 'schema/'
-            schema_dict = self._transmit(self._session().get, url)
-            return TastySchema(schema_dict, url)
-        except (KeyError, ResourceDeleted):
-            raise NonExistantResource(url)
+        url += 'schema/'
+        schema_dict = self._transmit(self._session().get, url)
+        return TastySchema(schema_dict, url)
+
+    def resources(self):
+        """Return the resources available from this API.
+
+        :returns: A list of available resources as strings.
+        :rtype: list
+        :raises: CannotConnectToAddress
+        """
+        return self._transmit(self._session().get, self.address()).keys()
