@@ -56,16 +56,21 @@ class Resource(_BASE_META_BRIDGE, object):
 
     api_url = None
     """(str) - The URL to the TastyPie API (eg. http://localhost/app_name/api/v1/)."""
+
     resource_name = None
     """(str) - The name of the resource. Defined by the 'resource_name' class
-        variable in the Resource's class Meta."""
+    variable in the Resource's class Meta."""
+
     auth = None
     """(:py:class:`~tastytopping.auth.AuthBase`) - The Authorization to use with
-        the resource. Note that because authorization applies to all resources
-        of a given type, changing the auth will affect all instances of a
-        Resource, as well as the derived Resource class itself. The
-        :doc:`auth` page goes into more detail.
-        """
+    the resource. Note that because authorization applies to all resources
+    of a given type, changing the auth will affect all instances of a
+    Resource, as well as the derived Resource class itself. The
+    :doc:`auth` page goes into more detail.
+    """
+
+    verify = True
+    """(bool) - Sets whether the SSL certificate of the API should be verified."""
 
     _factory = None
     _alive = set()
@@ -84,6 +89,7 @@ class Resource(_BASE_META_BRIDGE, object):
     _filter_field_lock = PickleLock()
 
     def __init__(self, **kwargs):
+        super(Resource, self).__init__()
         fields, uri = self._get_fields_and_uri_if_in_kwargs(**kwargs)
         self._set_uri(uri)
         self._set('_resource_fields', fields)
@@ -242,6 +248,7 @@ class Resource(_BASE_META_BRIDGE, object):
                     cls._class_api = TastyApi(cls.api_url)
                     if cls._auth:
                         cls._class_api.auth = cls._auth
+                    cls._class_api.verify = cls.verify
         return cls._class_api
 
     @classmethod
@@ -504,7 +511,7 @@ class Resource(_BASE_META_BRIDGE, object):
         type(self)._factory = state.pop('factory_type')(self.api_url)
         for member, value in state.items():
             self._set(member, value)
-        self._factory._classes[self.resource_name] = self.__class__
+        setattr(self._factory, self.resource_name, self.__class__)
 
     @staticmethod
     def _specialise(name, attrs):
